@@ -14,7 +14,10 @@ LDAPObject_modify(LDAPObject *self, PyObject *args)
 	const char *dn;
 	PyObject *attributes;
 	LDAPMod **mods;
+	PyObject *controls = NULL;
+	LDAPObjectControl *ldapoc = NULL;
 	LDAPControl **sctrls = NULL;
+	LDAPControl **cctrls = NULL;
 	int rc;
 	int msgid;
 
@@ -23,15 +26,21 @@ LDAPObject_modify(LDAPObject *self, PyObject *args)
 		return NULL;
 	}
 
-	if (!PyArg_ParseTuple(args, "sO", &dn, &attributes))
+	if (!PyArg_ParseTuple(args, "sO|O!", &dn, &attributes, &LDAPObjectControlType, &controls))
 		return NULL;
 
 	mods = python2LDAPMods(attributes);
 	if (mods == NULL)
 		return NULL;
 
+	if (controls) {
+		ldapoc = (LDAPObjectControl *)controls;
+		sctrls = ldapoc->sctrls;
+		cctrls = ldapoc->cctrls;
+	}
+
 	LDAP_BEGIN_ALLOW_THREADS
-	rc = ldap_modify_ext(self->ldap, dn, mods, sctrls, NULL, &msgid);
+	rc = ldap_modify_ext(self->ldap, dn, mods, sctrls, cctrls, &msgid);
 	LDAP_END_ALLOW_THREADS
 	free_LDAPMods(mods);
 	if (rc != LDAP_SUCCESS) {
